#
# spec file for package xdg-user-dirs-gtk
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xdg-user-dirs-gtk
Version:        0.14
Release:        1.2
Summary:        Xdg-user-dir support for Gnome and Gtk+ applications
License:        GPL-2.0-or-later
Group:          System/GUI/GNOME
URL:            http://download.gnome.org/sources/xdg-user-dirs-gtk
Source0:        %{name}-%{version}.tar.zst
# PATCH-FIX-UPSTREAM xdg-user-dirs-gtk-XFCE-LXDE-autostart.patch fdo#33107 gber@opensuse.org -- Start xdg-user-dirs-gtk in Xfce sessions as well
Patch1:         %{name}-XFCE-autostart.patch

BuildRequires:  desktop-file-utils
BuildRequires:  meson >= 1.0
BuildRequires:  pkgconfig
BuildRequires:  xdg-user-dirs
BuildRequires:  pkgconfig(gtk+-3.0)
Requires:       xdg-user-dirs

%description
A companion to xdg-user-dirs that integrates it into the Gnome desktop
and Gtk+ applications. Presents a dialog when a user changes locales
to help move they standard user directories to the correct names.

%lang_package

%prep
%autosetup -p1

%build
%meson \
	%{nil}
%meson_build

%install
%meson_install

%find_lang %{name}

%check
desktop-file-validate %{buildroot}%{_sysconfdir}/xdg/autostart/user-dirs-update-gtk.desktop
desktop-file-validate %{buildroot}%{_datadir}/applications/user-dirs-update-gtk.desktop

%files
%license COPYING
%doc AUTHORS README ChangeLog
%{_bindir}/xdg-user-dirs-gtk-update
%config(noreplace) %{_sysconfdir}/xdg/autostart/user-dirs-update-gtk.desktop
%{_datadir}/applications/user-dirs-update-gtk.desktop

%files lang -f %{name}.lang

%changelog
* Sun Jan 19 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.14:
  + build: Respect directory options in post install script
  + desktop: Fix translatable string merging
  + meson:
  - Bump minimum version to 1.0.0
  - Use SPDX for license
- Rebase patch with quilt.
* Sat Jan 18 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.13:
  + meson:
  - Do not fail if destdir isn't set
  - Install user-dirs-update-gtk.desktop in the correct datadir
- Drop fix-desktop-file-install-dir.patch: Fixed upstream.
- Add desktop-file-utils and check section: Validate desktop files
  during build.
- Mark autostart desktop file as config.
* Mon Jan 13 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.12:
  + Replace autotools with meson
  + update: Set wm_class to match .desktop file name
  + data: Also install desktop file into datadir
  + Updated translations.
- Add meson BuildRequires and macros, clean up old macros and
  exports.
- Drop gnome-common and intltool BuildRequires: No longer needed
  nor used.
- Add fix-desktop-file-install-dir.patch: Install desktop file in
  correct dir.
* Tue Jul 16 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.11+11:
  + Refactor code.
  + Converted tabs to spaces
  + build: Distribute autogen.sh
  + update: Set wm_class to match .desktop file name
  + data: Also install desktop file into datadir
  + configure.ac: Replace defunct Bugzilla with GitLab URI
- Drop obsolete update-desktop-files BuildRequires and macro.
- Replace gtk3-devel with pkgconfig(gtk+-3.0) BuildRequires, and
  add pkgconfig BuildRequires.
- Rebase patch.
* Tue Sep 12 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Stop passing -Wno-error=deprecated-declarations, no longer
  needed.
* Mon Mar 27 2023 Andreas Schwab <schwab@suse.de>
- Build with %%optflags
- Don't treat -Wcast-align as error
* Fri Oct 14 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.11:
  + Updated translations.
* Thu Sep 16 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Thu Oct  3 2019 bjorn.lie@gmail.com
- Update to version 0.10+13:
  + Comment invalid <category> in DOAP file to pass git pre-receive
    hook.
  + Make the 'Don't ask again' checkbox work properly.
  + Updated translations.
- Switch to git checkout, current master, via source service,
  explicit commit.
- Add gnome-common BuildRequires and pass autogen.sh, needed to
  bootstrap the checkout.
- Also pass export CFLAGS='-Wno-error=deprecated-declarations'.
- Use modern macros and tweak Summary to silence rpmlint.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Mon Feb  4 2013 p.drouand@gmail.com
- Update to version 0.10:
  + Use new location for GTK+ bookmarks file.
* Wed Apr  4 2012 vuntz@opensuse.org
- Update to version 0.9:
  + Port to Gtk 3
  + Add Unity and LXDE to desktop file OnlyShowIn
  + Faster startup by only initializing Gtk when needed
  + Updated ranslations.
- Drop xdg-user-dirs-gtk-LXDE-autostart.patch: fixed upstream.
- Rebase xdg-user-dirs-gtk-XFCE-autostart.patch.
- Remove perl-XML-Parser BuildRequires: it was only needed when it
  was not required by intltool.
- Change gtk2-devel BuildRequires to gtk3-devel, following port to
  GTK+ 3.
* Sun Feb 27 2011 aj@suse.de
- Change lang package Requires to Recommends since it is not
  mandatory at runtime.
* Wed Dec 29 2010 gber@opensuse.org
- Add xdg-user-dirs-gtk-XFCE-autostart.patch in order to
  start in Xfce sessions as well.
* Tue Feb  9 2010 andrea@opensuse.org
- Add xdg-user-dirs-gtk-LXDE-autostart.patch to also autostart
  xdg-user-dirs in LXDE.
* Mon Feb 16 2009 sbrabec@suse.cz
- Added support for translation-update-upstream (FATE#301344).
* Thu Dec 11 2008 coolo@suse.de
- require the translations
* Wed Sep 10 2008 jpr@suse.de
- Update to version 0.8:
  + Translation updates
* Thu Mar 20 2008 jpr@suse.de
- Initial check of xdg-user-dirs-gtk, to manager updating xdg user
  dirs on login
